@@ -21,15 +21,26 @@ service_option = cfg.BoolOpt("manila",
                              help="Whether or not manila is expected to be "
                                   "available")
 
+manila_scope_enforcement = cfg.BoolOpt('manila',
+                                       default=False,
+                                       help="Does the Share service API "
+                                            "policies enforce scope? "
+                                            "This configuration value should "
+                                            "be same as manila.conf: "
+                                            "[oslo_policy].enforce_scope "
+                                            "option.")
+
 share_group = cfg.OptGroup(name="share", title="Share Service Options")
 
 ShareGroup = [
     cfg.StrOpt("min_api_microversion",
                default="2.0",
                help="The minimum api microversion is configured to be the "
-                    "value of the minimum microversion supported by Manila."),
+                    "value of the minimum microversion supported by Manila. "
+                    "This value is only used to validate the versions "
+                    "response from Manila."),
     cfg.StrOpt("max_api_microversion",
-               default="2.61",
+               default="2.70",
                help="The maximum api microversion is configured to be the "
                     "value of the latest microversion supported by Manila."),
     cfg.StrOpt("region",
@@ -129,6 +140,16 @@ ShareGroup = [
                help="Backend capability to create consistent snapshots of "
                     "share group members. Will be used with creation "
                     "of new share group types as group spec."),
+    cfg.BoolOpt("capability_thin_provisioned",
+                default=False,
+                help="Defines whether to create shares as thin provisioned, "
+                     "adding the extra spec 'thin_provisioning' as 'True' for "
+                     "setting up the custom share types. It may be useful to "
+                     "run tempest with  back end storage systems without much "
+                     "space. Take care enabling it, the manila scheduler "
+                     "capability filter will request this capability in all "
+                     "share types and the the capacity filter will allow "
+                     "oversubscription."),
     cfg.StrOpt("share_network_id",
                default="",
                help="Some backend drivers requires share network "
@@ -266,6 +287,16 @@ ShareGroup = [
                 default=False,
                 help="Defines whether to run share servers migration tests. "
                      "Enable this option if the used driver supports it."),
+    cfg.BoolOpt("run_share_server_multiple_subnet_tests",
+                default=False,
+                help="Defines whether to run the share server multiple "
+                     "subnets tests. Enable this option if the used driver "
+                     "supports it."),
+    cfg.BoolOpt("run_network_allocation_update_tests",
+                default=False,
+                help="Defines whether to run the network allocation update "
+                     "tests. Enable this option if the used driver "
+                     "supports it."),
 
     cfg.StrOpt("image_with_share_tools",
                default="manila-service-image-master",
